==> guile_0.4.0-3.tar.gz: guile-0.4.0/libguile/boolean.c <==
/*	Copyright (C) 1995 Free Software Foundation, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, the Free Software Foundation gives permission
 * for additional uses of the text contained in its release of GUILE.
 *
 * The exception is that, if you link the GUILE library with other files
 * to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the GUILE library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the
 * Free Software Foundation under the name GUILE.  If you copy
 * code from other Free Software Foundation releases into a copy of
 * GUILE, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for GUILE, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.  
 */


#include <stdio.h>
#include "_scm.h"



PROC (s_not, "not", 1, 0, 0, scm_not);
#ifdef __STDC__
SCM
scm_not(SCM x)
#else
SCM
scm_not(x)
     SCM x;
#endif
{
	return FALSEP(x) ? BOOL_T : BOOL_F;
}



PROC (s_strict_and, "strict-and", 2, 0, 0, scm_strict_and);
#ifdef __STDC__
SCM
scm_strict_and(SCM x, SCM y)
#else
SCM
scm_strict_and(x, y)
     SCM x;
     SCM y;
#endif
{
	return (((x != BOOL_F) && (y != BOOL_F))
		? BOOL_T
		: BOOL_F);
}

#ifdef __STDC__
SCM
scm_strict_or(SCM x, SCM y)
#else
SCM
scm_strict_or(x, y)
     SCM x;
     SCM y;
#endif
{
	return (((x != BOOL_F) || (y != BOOL_F))
		? BOOL_T
		: BOOL_F);
}


PROC (s_boolean_p, "boolean?", 1, 0, 0, scm_boolean_p);
#ifdef __STDC__
SCM
scm_boolean_p(SCM obj)
#else
SCM
scm_boolean_p(obj)
     SCM obj;
#endif
{
	if (BOOL_F==obj) return BOOL_T;
	if (BOOL_T==obj) return BOOL_T;
	return BOOL_F;
}


#ifdef __STDC__
void
scm_init_boolean (void)
#else
void
scm_init_boolean ()
#endif
{
#include "boolean.x"
}

==> guile-1.0.tar.gz: guile-1.0/libguile/boolean.c <==
/*	Copyright (C) 1995,1996 Free Software Foundation, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, the Free Software Foundation gives permission
 * for additional uses of the text contained in its release of GUILE.
 *
 * The exception is that, if you link the GUILE library with other files
 * to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the GUILE library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the
 * Free Software Foundation under the name GUILE.  If you copy
 * code from other Free Software Foundation releases into a copy of
 * GUILE, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for GUILE, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.  
 */


#include <stdio.h>
#include "_scm.h"

#include "boolean.h"



SCM_PROC(s_not, "not", 1, 0, 0, scm_not);

SCM
scm_not(x)
     SCM x;
{
	return SCM_FALSEP(x) ? SCM_BOOL_T : SCM_BOOL_F;
}


SCM_PROC(s_boolean_p, "boolean?", 1, 0, 0, scm_boolean_p);

SCM
scm_boolean_p(obj)
     SCM obj;
{
	if (SCM_BOOL_F==obj) return SCM_BOOL_T;
	if (SCM_BOOL_T==obj) return SCM_BOOL_T;
	return SCM_BOOL_F;
}



void
scm_init_boolean ()
{
#include "boolean.x"
}
